==> flywaymigrationconstruct-0.0.15.tar.gz: package/API.md <==
# API Reference <a name="API Reference"></a>

## Constructs <a name="Constructs"></a>

### FlywayConstruct <a name="flywaymigrationconstruct.FlywayConstruct"></a>

#### Initializer <a name="flywaymigrationconstruct.FlywayConstruct.Initializer"></a>

```typescript
import { FlywayConstruct } from 'flywaymigrationconstruct'

new FlywayConstruct(scope: Construct, id: string, VPC: Vpc, subnet: SubnetSelection, securityGroup: SecurityGroup, bucketName: string, url: string, user: string, password: string)
```

##### `scope`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `id`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.id"></a>

- *Type:* `string`

---

##### `VPC`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.VPC"></a>

- *Type:* [`@aws-cdk/aws-ec2.Vpc`](#@aws-cdk/aws-ec2.Vpc)

---

##### `subnet`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.subnet"></a>

- *Type:* [`@aws-cdk/aws-ec2.SubnetSelection`](#@aws-cdk/aws-ec2.SubnetSelection)

---

##### `securityGroup`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.securityGroup"></a>

- *Type:* [`@aws-cdk/aws-ec2.SecurityGroup`](#@aws-cdk/aws-ec2.SecurityGroup)

---

##### `bucketName`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.bucketName"></a>

- *Type:* `string`

---

##### `url`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.url"></a>

- *Type:* `string`

---

##### `user`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.user"></a>

- *Type:* `string`

---

##### `password`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.password"></a>

- *Type:* `string`

---



#### Properties <a name="Properties"></a>

##### `flywayLambdaMigration`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.property.flywayLambdaMigration"></a>

- *Type:* [`@aws-cdk/aws-lambda.Function`](#@aws-cdk/aws-lambda.Function)

---

==> flywaymigrationconstruct-0.0.44.tar.gz: package/API.md <==
# API Reference <a name="API Reference"></a>

## Constructs <a name="Constructs"></a>

### FlywayConstruct <a name="flywaymigrationconstruct.FlywayConstruct"></a>

#### Initializer <a name="flywaymigrationconstruct.FlywayConstruct.Initializer"></a>

```typescript
import { FlywayConstruct } from 'flywaymigrationconstruct'

new FlywayConstruct(scope: Construct, id: string, VPC: Vpc, subnet: SubnetSelection, securityGroup: SecurityGroup, bucketName: string, arn: string)
```

##### `scope`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `id`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.id"></a>

- *Type:* `string`

---

##### `VPC`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.VPC"></a>

- *Type:* [`@aws-cdk/aws-ec2.Vpc`](#@aws-cdk/aws-ec2.Vpc)

---

##### `subnet`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.subnet"></a>

- *Type:* [`@aws-cdk/aws-ec2.SubnetSelection`](#@aws-cdk/aws-ec2.SubnetSelection)

---

##### `securityGroup`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.securityGroup"></a>

- *Type:* [`@aws-cdk/aws-ec2.SecurityGroup`](#@aws-cdk/aws-ec2.SecurityGroup)

---

##### `bucketName`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.bucketName"></a>

- *Type:* `string`

---

##### `arn`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.parameter.arn"></a>

- *Type:* `string`

---



#### Properties <a name="Properties"></a>

##### `flywayLambdaMigration`<sup>Required</sup> <a name="flywaymigrationconstruct.FlywayConstruct.property.flywayLambdaMigration"></a>

- *Type:* [`@aws-cdk/aws-lambda.Function`](#@aws-cdk/aws-lambda.Function)

---
